@@ -19,6 +19,7 @@
     GyMMM => "MMM y G",
     GyMMMEd => "E d. MMM y G",
     GyMMMd => "d. MMM y G",
+    GyMd => "d.M.y GGGGG",
     H => "HH",
     Hm => "HH.mm",
     Hms => "HH.mm.ss",
@@ -29,8 +30,8 @@
     MMM => "MMM",
     MMMEd => "E d. MMM",
     MMMMEd => "E d. MMMM",
-    "MMMMW-count-one" => "'uge' W 'i' MMMM",
-    "MMMMW-count-other" => "'uge' W 'i' MMMM",
+    "MMMMW-count-one" => "W. 'uge' 'i' MMMM",
+    "MMMMW-count-other" => "W. 'uge' 'i' MMMM",
     MMMMd => "d. MMMM",
     MMMd => "d. MMM",
     MMdd => "dd.MM",
@@ -271,5 +272,5 @@
   time_format_medium => "HH.mm.ss",
   time_format_short => "HH.mm",
   variant => undef,
-  version => 39,
+  version => 40,
 }
