@@ -19,6 +19,7 @@
     GyMMM => "MMM y G",
     GyMMMEd => "E, d MMM y G",
     GyMMMd => "d MMM y G",
+    GyMd => "d/M/y GGGGG",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -146,7 +147,7 @@
     "Jun",
     "Jul",
     "Aug",
-    "Sep",
+    "Sept",
     "Oct",
     "Nov",
     "Dec",
@@ -188,7 +189,7 @@
     "Jun",
     "Jul",
     "Aug",
-    "Sep",
+    "Sept",
     "Oct",
     "Nov",
     "Dec",
@@ -270,5 +271,5 @@
   time_format_medium => "h:mm:ss a",
   time_format_short => "h:mm a",
   variant => undef,
-  version => 38,
+  version => 40,
 }
