@@ -12,27 +12,28 @@
     EBhms => "E h:mm:ss B",
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
-    Ed => "d, E",
+    Ed => "E d",
     Ehm => "E h:mm a",
     Ehms => "E h:mm:ss a",
-    Gy => "G y",
-    GyMMM => "G y MMM",
-    GyMMMEd => "G y MMM d, E",
-    GyMMMd => "G y MMM d",
+    Gy => "y G",
+    GyMMM => "MMM y G",
+    GyMMMEd => "E\N{U+2e41} d MMM\N{U+2e41} y G",
+    GyMMMd => "d MMM\N{U+2e41} y G",
+    GyMd => "d-M-y GGGGG",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
     Hmsv => "HH:mm:ss v",
     Hmv => "HH:mm v",
     M => "L",
-    MEd => "MM-dd, E",
+    MEd => "E d-M",
     MMM => "LLL",
-    MMMEd => "MMM d, E",
+    MMMEd => "E d MMM",
     "MMMMW-count-one" => "\N{U+1e934}\N{U+1e92e}\N{U+1e932}\N{U+1e93c}\N{U+1e92b}\N{U+1e92a}\N{U+1e92b} W \N{U+1e932}\N{U+1e923}\N{U+1e92b}\N{U+1e92a} MMMM",
     "MMMMW-count-other" => "\N{U+1e934}\N{U+1e92e}\N{U+1e932}\N{U+1e93c}\N{U+1e92b}\N{U+1e92a}\N{U+1e92b} W \N{U+1e932}\N{U+1e923}\N{U+1e92b}\N{U+1e92a} MMMM",
-    MMMMd => "MMMM d",
-    MMMd => "MMM d",
-    Md => "MM-dd",
+    MMMMd => "d MMMM",
+    MMMd => "d MMM",
+    Md => "d-M",
     d => "d",
     h => "h a",
     hm => "h:mm a",
@@ -41,25 +42,25 @@
     hmv => "h:mm a v",
     ms => "mm:ss",
     y => "y",
-    yM => "y-MM",
-    yMEd => "y-MM-dd, E",
-    yMMM => "y MMM",
-    yMMMEd => "y MMM d, E",
-    yMMMM => "y MMMM",
-    yMMMd => "y MMM d",
-    yMd => "y-MM-dd",
-    yQQQ => "y QQQ",
-    yQQQQ => "y QQQQ",
+    yM => "M-y",
+    yMEd => "E\N{U+2e41} d-M-y",
+    yMMM => "MMM y",
+    yMMMEd => "E\N{U+2e41} d MMM\N{U+2e41} y",
+    yMMMM => "MMMM y",
+    yMMMd => "d MMM\N{U+2e41} y",
+    yMd => "d-M-y",
+    yQQQ => "QQQ y",
+    yQQQQ => "QQQQ y",
     "yw-count-one" => "\N{U+1e934}\N{U+1e92e}\N{U+1e932}\N{U+1e93c}\N{U+1e92b}\N{U+1e92a}\N{U+1e92b} w \N{U+1e932}\N{U+1e923}\N{U+1e92b}\N{U+1e92a} Y",
     "yw-count-other" => "\N{U+1e934}\N{U+1e92e}\N{U+1e932}\N{U+1e93c}\N{U+1e92b}\N{U+1e92a}\N{U+1e92b} w \N{U+1e932}\N{U+1e923}\N{U+1e92b}\N{U+1e92a} Y",
   },
   code => "ff-Adlm-MR",
-  date_format_full => "y MMMM d, EEEE",
-  date_format_long => "y MMMM d",
-  date_format_medium => "y MMM d",
-  date_format_short => "y-MM-dd",
-  datetime_format_full => "{1}{0}",
-  datetime_format_long => "{1} {0}",
+  date_format_full => "EEEE d MMMM\N{U+2e41} y",
+  date_format_long => "d MMMM\N{U+2e41} y",
+  date_format_medium => "d MMM\N{U+2e41} y",
+  date_format_short => "d-M-y",
+  datetime_format_full => "{1} \N{U+1e909} {0}",
+  datetime_format_long => "{1} \N{U+1e909} {0}",
   datetime_format_medium => "{1} {0}",
   datetime_format_short => "{1} {0}",
   day_format_abbreviated => [
@@ -147,7 +148,7 @@
     "\N{U+1e905}\N{U+1e92d}\N{U+1e924}\N{U+1e93c}\N{U+1e92e}",
     "\N{U+1e912}\N{U+1e922}\N{U+1e92a}\N{U+1e933}\N{U+1e92e}",
     "\N{U+1e914}\N{U+1e92e}\N{U+1e924}\N{U+1e92e}",
-    "\N{U+1e910}\N{U+1e926}\N{U+1e92e}\N{U+1e931}\N{U+1e93c}\N{U+1e92e}",
+    "\N{U+1e904}\N{U+1e92e}\N{U+1e931}\N{U+1e93c}\N{U+1e92e}",
   ],
   month_format_narrow => [
     "\N{U+1e905}",
@@ -175,12 +176,12 @@
     "\N{U+1e905}\N{U+1e92d}\N{U+1e924}\N{U+1e93c}\N{U+1e92e}",
     "\N{U+1e912}\N{U+1e922}\N{U+1e92a}\N{U+1e933}\N{U+1e92e}",
     "\N{U+1e914}\N{U+1e92e}\N{U+1e924}\N{U+1e92e}",
-    "\N{U+1e910}\N{U+1e926}\N{U+1e92e}\N{U+1e931}\N{U+1e93c}\N{U+1e92e}",
+    "\N{U+1e904}\N{U+1e92e}\N{U+1e931}\N{U+1e93c}\N{U+1e92e}",
   ],
   month_stand_alone_abbreviated => [
     "\N{U+1e905}\N{U+1e92d}\N{U+1e945}\N{U+1e924}",
     "\N{U+1e915}\N{U+1e92e}\N{U+1e924}",
-    "\N{U+1e904}\N{U+1e92e}\N{U+1e945}\N{U+1e934}",
+    "\N{U+1e910}\N{U+1e926}\N{U+1e92e}\N{U+1e945}\N{U+1e934}",
     "\N{U+1e905}\N{U+1e92b}\N{U+1e945}\N{U+1e93c}",
     "\N{U+1e901}\N{U+1e935}\N{U+1e945}\N{U+1e936}",
     "\N{U+1e911}\N{U+1e92e}\N{U+1e92a}",
@@ -202,7 +203,7 @@
     "\N{U+1e914}",
     "\N{U+1e905}",
     "\N{U+1e912}",
-    "\N{U+1e904}",
+    "\N{U+1e914}",
     "\N{U+1e904}",
   ],
   month_stand_alone_wide => [
@@ -217,7 +218,7 @@
     "\N{U+1e905}\N{U+1e92d}\N{U+1e924}\N{U+1e93c}\N{U+1e92e}",
     "\N{U+1e912}\N{U+1e922}\N{U+1e92a}\N{U+1e933}\N{U+1e92e}",
     "\N{U+1e914}\N{U+1e92e}\N{U+1e924}\N{U+1e92e}",
-    "\N{U+1e910}\N{U+1e926}\N{U+1e92e}\N{U+1e931}\N{U+1e93c}\N{U+1e92e}",
+    "\N{U+1e904}\N{U+1e92e}\N{U+1e931}\N{U+1e93c}\N{U+1e92e}",
   ],
   name => "Fulah Mauritania Adlam",
   native_language => "\N{U+1e906}\N{U+1e935}\N{U+1e924}\N{U+1e922}\N{U+1e92a}",
@@ -268,5 +269,5 @@
   time_format_medium => "h:mm:ss a",
   time_format_short => "h:mm a",
   variant => undef,
-  version => 39,
+  version => 40,
 }
