@@ -4,21 +4,22 @@
     "f",
   ],
   available_formats => {
-    Bh => "h B",
-    Bhm => "h:mm B",
-    Bhms => "h:mm:ss B",
+    Bh => "hB",
+    Bhm => "h:mmB",
+    Bhms => "h:mm:ssB",
     E => "ccc",
-    EBhm => "E h:mm B",
-    EBhms => "E h:mm:ss B",
+    EBhm => "E h:mmB",
+    EBhms => "E h:mm:ssB",
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
     Ed => "E, d",
     Ehm => "E h:mma",
     Ehms => "E h:mm:ss a",
     Gy => "y G",
-    GyMMM => "MMM y G",
+    GyMMM => "LLL y G",
     GyMMMEd => "E, d MMM y G",
     GyMMMd => "d MMM y G",
+    GyMd => "d/M/y GGGGG",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -44,20 +45,20 @@
     hmv => "h:mma v",
     ms => "mm:ss",
     y => "y",
-    yM => "M/y",
+    yM => "L/y",
     yMEd => "E, d/M/y",
-    yMM => "MM/y",
-    yMMM => "MMM y",
+    yMM => "LL/y",
+    yMMM => "LLL Y",
     yMMMEd => "E, d MMM y",
     yMMMM => "LLLL y",
     yMMMd => "d MMM y",
-    yMd => "M/d/y",
+    yMd => "d/M/y",
     yQQQ => "QQQ y",
     yQQQQ => "QQQQ y",
-    "yw-count-few" => "'seachdain' w 'dhe' y",
-    "yw-count-one" => "'seachdain' w 'dhe' y",
-    "yw-count-other" => "'seachdain' w 'dhe' y",
-    "yw-count-two" => "'seachdain' w 'dhe' y",
+    "yw-count-few" => "'seachdain' w 'dhe' Y",
+    "yw-count-one" => "'seachdain' w 'dhe' Y",
+    "yw-count-other" => "'seachdain' w 'dhe' Y",
+    "yw-count-two" => "'seachdain' w 'dhe' Y",
   },
   code => "gd-GB",
   date_format_full => "EEEE, d'mh' MMMM y",
@@ -135,9 +136,9 @@
     "An d\N{U+00e8}idh Chr\N{U+00ec}osta",
   ],
   first_day_of_week => 1,
-  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
+  glibc_date_1_format => "%a %d %b %Y %T %Z",
   glibc_date_format => "%d/%m/%y",
-  glibc_datetime_format => "%a %d %b %Y %T %Z",
+  glibc_datetime_format => "%a %d %b %Y %T",
   glibc_time_12_format => "%I:%M:%S %p",
   glibc_time_format => "%r",
   language => "Scottish Gaelic",
@@ -274,5 +275,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 33,
+  version => 40,
 }
