@@ -19,16 +19,20 @@
     GyMMM => "MMM y G",
     GyMMMEd => "E, d. MMM y G",
     GyMMMd => "d. MMM y G",
+    GyMd => "d.M.y GGGGG",
     H => "H 'hod\N{U+017a}'.",
     Hm => "H:mm 'hod\N{U+017a}'.",
     Hms => "H:mm:ss",
-    Hmsv => "HH:mm:ss v",
-    Hmv => "HH:mm v",
+    Hmsv => "H:mm:ss v",
+    Hmv => "H:mm v",
     M => "L",
     MEd => "E, d.M.",
     MMM => "LLL",
     MMMEd => "E, d. MMM",
-    "MMMMW-count-other" => "'week' W 'of' MMMM",
+    "MMMMW-count-few" => "'tyd\N{U+017a}e\N{U+0144}' W MMMM",
+    "MMMMW-count-one" => "'tyd\N{U+017a}e\N{U+0144}' W MMMM",
+    "MMMMW-count-other" => "'tyd\N{U+017a}e\N{U+0144}' W MMMM",
+    "MMMMW-count-two" => "'tyd\N{U+017a}e\N{U+0144}' W MMMM",
     MMMMd => "d MMMM",
     MMMd => "d. MMM",
     Md => "d.M.",
@@ -49,7 +53,10 @@
     yMd => "d.M.y",
     yQQQ => "QQQ y",
     yQQQQ => "QQQQ y",
-    "yw-count-other" => "'week' w 'of' Y",
+    "yw-count-few" => "'tyd\N{U+017a}e\N{U+0144}' w 'l\N{U+011b}ta' Y",
+    "yw-count-one" => "'tyd\N{U+017a}e\N{U+0144}' w 'l\N{U+011b}ta' Y",
+    "yw-count-other" => "'tyd\N{U+017a}e\N{U+0144}' w 'l\N{U+011b}ta' Y",
+    "yw-count-two" => "'tyd\N{U+017a}e\N{U+0144}' w 'l\N{U+011b}ta' Y",
   },
   code => "hsb-DE",
   date_format_full => "EEEE, d. MMMM y",
@@ -266,5 +273,5 @@
   time_format_medium => "H:mm:ss",
   time_format_short => "H:mm 'hod\N{U+017a}'.",
   variant => undef,
-  version => 39,
+  version => 40,
 }
