@@ -17,8 +17,9 @@
     Ehms => "E h:mm:ss a",
     Gy => "y G",
     GyMMM => "MMM G y",
-    GyMMMEd => "E, d MMM y G",
+    GyMMMEd => "E, MMM d, y G",
     GyMMMd => "d MMM y G",
+    GyMd => "dd-MM-y",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -79,13 +80,13 @@
     "\N{U+0930}",
   ],
   day_format_wide => [
-    "\N{U+0938}\N{U+094b}\N{U+092e}\N{U+0935}\N{U+093e}\N{U+0930}",
-    "\N{U+092e}\N{U+0902}\N{U+0917}\N{U+0932}\N{U+0935}\N{U+093e}\N{U+0930}",
-    "\N{U+092c}\N{U+0941}\N{U+0927}\N{U+0935}\N{U+093e}\N{U+0930}",
-    "\N{U+0917}\N{U+0941}\N{U+0930}\N{U+0941}\N{U+0935}\N{U+093e}\N{U+0930}",
-    "\N{U+0936}\N{U+0941}\N{U+0915}\N{U+094d}\N{U+0930}\N{U+0935}\N{U+093e}\N{U+0930}",
-    "\N{U+0936}\N{U+0928}\N{U+093f}\N{U+0935}\N{U+093e}\N{U+0930}",
-    "\N{U+0930}\N{U+0935}\N{U+093f}\N{U+0935}\N{U+093e}\N{U+0930}",
+    "\N{U+0938}\N{U+094b}\N{U+092e} \N{U+0926}\N{U+093f}\N{U+0928}",
+    "\N{U+092e}\N{U+0902}\N{U+0917}\N{U+0932} \N{U+0926}\N{U+093f}\N{U+0928}",
+    "\N{U+092c}\N{U+0941}\N{U+0927} \N{U+0926}\N{U+093f}\N{U+0928}",
+    "\N{U+092c}\N{U+0943}\N{U+0939}\N{U+0938}\N{U+094d}\N{U+092a}\N{U+0924}\N{U+093f} \N{U+0926}\N{U+093f}\N{U+0928}",
+    "\N{U+0936}\N{U+0941}\N{U+0915}\N{U+094d}\N{U+0930} \N{U+0926}\N{U+093f}\N{U+0928}",
+    "\N{U+0936}\N{U+0928}\N{U+093f} \N{U+0926}\N{U+093f}\N{U+0928}",
+    "\N{U+0930}\N{U+0935}\N{U+093f} \N{U+0926}\N{U+093f}\N{U+0928}",
   ],
   day_stand_alone_abbreviated => [
     "\N{U+0938}\N{U+094b}\N{U+092e}",
@@ -106,25 +107,25 @@
     "\N{U+0930}",
   ],
   day_stand_alone_wide => [
-    "\N{U+0938}\N{U+094b}\N{U+092e}\N{U+0935}\N{U+093e}\N{U+0930}",
-    "\N{U+092e}\N{U+0902}\N{U+0917}\N{U+0932}\N{U+0935}\N{U+093e}\N{U+0930}",
-    "\N{U+092c}\N{U+0941}\N{U+0927}\N{U+0935}\N{U+093e}\N{U+0930}",
-    "\N{U+0917}\N{U+0941}\N{U+0930}\N{U+0941}\N{U+0935}\N{U+093e}\N{U+0930}",
-    "\N{U+0936}\N{U+0941}\N{U+0915}\N{U+094d}\N{U+0930}\N{U+0935}\N{U+093e}\N{U+0930}",
-    "\N{U+0936}\N{U+0928}\N{U+093f}\N{U+0935}\N{U+093e}\N{U+0930}",
-    "\N{U+0930}\N{U+0935}\N{U+093f}\N{U+0935}\N{U+093e}\N{U+0930}",
+    "\N{U+0938}\N{U+094b}\N{U+092e} \N{U+0926}\N{U+093f}\N{U+0928}",
+    "\N{U+092e}\N{U+0902}\N{U+0917}\N{U+0932} \N{U+0926}\N{U+093f}\N{U+0928}",
+    "\N{U+092c}\N{U+0941}\N{U+0927} \N{U+0926}\N{U+093f}\N{U+0928}",
+    "\N{U+092c}\N{U+0943}\N{U+0939}\N{U+0938}\N{U+094d}\N{U+092a}\N{U+0924}\N{U+093f} \N{U+0926}\N{U+093f}\N{U+0928}",
+    "\N{U+0936}\N{U+0941}\N{U+0915}\N{U+094d}\N{U+0930} \N{U+0926}\N{U+093f}\N{U+0928}",
+    "\N{U+0936}\N{U+0928}\N{U+093f} \N{U+0926}\N{U+093f}\N{U+0928}",
+    "\N{U+0930}\N{U+0935}\N{U+093f} \N{U+0926}\N{U+093f}\N{U+0928}",
   ],
   era_abbreviated => [
     "\N{U+0908}\N{U+0938}\N{U+093e}-\N{U+092a}\N{U+0942}\N{U+0930}\N{U+094d}\N{U+0935}",
-    "\N{U+0908}\N{U+0938}\N{U+094d}\N{U+0935}\N{U+0940}",
+    "\N{U+0908}\N{U+0938}\N{U+0935}\N{U+0940}",
   ],
   era_narrow => [
     "\N{U+0908}\N{U+0938}\N{U+093e}-\N{U+092a}\N{U+0942}\N{U+0930}\N{U+094d}\N{U+0935}",
-    "\N{U+0908}\N{U+0938}\N{U+094d}\N{U+0935}\N{U+0940}",
+    "\N{U+0908}\N{U+0938}\N{U+0935}\N{U+0940}",
   ],
   era_wide => [
     "\N{U+0908}\N{U+0938}\N{U+093e}-\N{U+092a}\N{U+0942}\N{U+0930}\N{U+094d}\N{U+0935}",
-    "\N{U+0908}\N{U+0938}\N{U+094d}\N{U+0935}\N{U+0940}",
+    "\N{U+0908}\N{U+0938}\N{U+0935}\N{U+0940}",
   ],
   first_day_of_week => 1,
   glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
@@ -149,7 +150,7 @@
   ],
   month_format_narrow => [
     "\N{U+091c}",
-    "\N{U+092b}\N{U+093c}",
+    "\N{U+092b}",
     "\N{U+092e}\N{U+093e}",
     "\N{U+0905}",
     "\N{U+092e}",
@@ -163,7 +164,7 @@
   ],
   month_format_wide => [
     "\N{U+091c}\N{U+0928}\N{U+0935}\N{U+0930}\N{U+0940}",
-    "\N{U+092b}\N{U+093c}\N{U+0930}\N{U+0935}\N{U+0930}\N{U+0940}",
+    "\N{U+092b}\N{U+0930}\N{U+0935}\N{U+0930}\N{U+0940}",
     "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
     "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}\N{U+0932}",
     "\N{U+092e}\N{U+0908}",
@@ -177,7 +178,7 @@
   ],
   month_stand_alone_abbreviated => [
     "\N{U+091c}\N{U+0928}\N{U+0970}",
-    "\N{U+092b}\N{U+093c}\N{U+0930}\N{U+0970}",
+    "\N{U+092b}\N{U+0930}\N{U+0970}",
     "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
     "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}\N{U+0932}",
     "\N{U+092e}\N{U+0908}",
@@ -191,7 +192,7 @@
   ],
   month_stand_alone_narrow => [
     "\N{U+091c}",
-    "\N{U+092b}\N{U+093c}",
+    "\N{U+092b}",
     "\N{U+092e}\N{U+093e}",
     "\N{U+0905}",
     "\N{U+092e}",
@@ -205,7 +206,7 @@
   ],
   month_stand_alone_wide => [
     "\N{U+091c}\N{U+0928}\N{U+0935}\N{U+0930}\N{U+0940}",
-    "\N{U+092b}\N{U+093c}\N{U+0930}\N{U+0935}\N{U+0930}\N{U+0940}",
+    "\N{U+092b}\N{U+0930}\N{U+0935}\N{U+0930}\N{U+0940}",
     "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
     "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}\N{U+0932}",
     "\N{U+092e}\N{U+0908}",
@@ -213,7 +214,7 @@
     "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+0908}",
     "\N{U+0905}\N{U+0917}\N{U+0938}\N{U+094d}\N{U+0924}",
     "\N{U+0938}\N{U+093f}\N{U+0924}\N{U+0902}\N{U+092c}\N{U+0930}",
-    "\N{U+0905}\N{U+0915}\N{U+094d}\N{U+0924}\N{U+0942}\N{U+092c}\N{U+0930}",
+    "\N{U+0905}\N{U+0915}\N{U+094d}\N{U+091f}\N{U+0942}\N{U+092c}\N{U+0930}",
     "\N{U+0928}\N{U+0935}\N{U+0902}\N{U+092c}\N{U+0930}",
     "\N{U+0926}\N{U+093f}\N{U+0938}\N{U+0902}\N{U+092c}\N{U+0930}",
   ],
@@ -236,10 +237,10 @@
     4,
   ],
   quarter_format_wide => [
-    "\N{U+092a}\N{U+0939}\N{U+0932}\N{U+0940} \N{U+0924}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
-    "\N{U+0926}\N{U+0942}\N{U+0938}\N{U+0930}\N{U+0940} \N{U+0924}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
-    "\N{U+0924}\N{U+0940}\N{U+0938}\N{U+0930}\N{U+0940} \N{U+0924}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
-    "\N{U+091a}\N{U+094c}\N{U+0925}\N{U+0940} \N{U+0924}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
+    "\N{U+092a}\N{U+0939}\N{U+093f}\N{U+0932} \N{U+0924}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
+    "\N{U+0926}\N{U+094b}\N{U+0938}\N{U+0930} \N{U+0924}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
+    "\N{U+0924}\N{U+0947}\N{U+0938}\N{U+0930} \N{U+0924}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
+    "\N{U+091a}\N{U+093e}\N{U+0930}\N{U+093f}\N{U+092e} \N{U+0924}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
   ],
   quarter_stand_alone_abbreviated => [
     "\N{U+0924}\N{U+093f}1",
@@ -254,10 +255,10 @@
     4,
   ],
   quarter_stand_alone_wide => [
-    "\N{U+092a}\N{U+0939}\N{U+0932}\N{U+0940} \N{U+0924}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
-    "\N{U+0926}\N{U+0942}\N{U+0938}\N{U+0930}\N{U+0940} \N{U+0924}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
-    "\N{U+0924}\N{U+0940}\N{U+0938}\N{U+0930}\N{U+0940} \N{U+0924}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
-    "\N{U+091a}\N{U+094c}\N{U+0925}\N{U+0940} \N{U+0924}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
+    "\N{U+092a}\N{U+0939}\N{U+093f}\N{U+0932} \N{U+0924}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
+    "\N{U+0926}\N{U+094b}\N{U+0938}\N{U+0930} \N{U+0924}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
+    "\N{U+0924}\N{U+0947}\N{U+0938}\N{U+0930} \N{U+0924}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
+    "\N{U+091a}\N{U+093e}\N{U+0930}\N{U+093f}\N{U+092e} \N{U+0924}\N{U+093f}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
   ],
   script => undef,
   territory => undef,
@@ -266,5 +267,5 @@
   time_format_medium => "h:mm:ss a",
   time_format_short => "h:mm a",
   variant => undef,
-  version => 39,
+  version => 40,
 }
