@@ -19,6 +19,7 @@
     GyMMM => "MMM y G",
     GyMMMEd => "E d. MMM y G",
     GyMMMd => "d. MMM y G",
+    GyMd => "dd.MM.y GGGGG",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -28,8 +29,8 @@
     MEd => "E d.M.",
     MMM => "LLL",
     MMMEd => "E d. MMM",
-    "MMMMW-count-one" => "W. 'uke' 'i' MMMM",
-    "MMMMW-count-other" => "W. 'uke' 'i' MMMM",
+    "MMMMW-count-one" => "'den' W. 'uken' 'i' MMMM",
+    "MMMMW-count-other" => "'den' W. 'uken' 'i' MMMM",
     MMMMd => "d. MMMM",
     MMMd => "d. MMM",
     MMdd => "d.M.",
@@ -270,5 +271,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 39,
+  version => 40,
 }
