@@ -16,9 +16,10 @@
     Ehm => "E h:mm a",
     Ehms => "E h:mm:ss a",
     Gy => "y '\N{U+0433}'. G",
-    GyMMM => "LLL y G",
+    GyMMM => "LLL y '\N{U+0433}'. G",
     GyMMMEd => "E, d MMM y '\N{U+0433}'. G",
     GyMMMd => "d MMM y '\N{U+0433}'. G",
+    GyMd => "dd.MM.y GGGGG",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -78,13 +79,13 @@
     "\N{U+0432}\N{U+0441}",
   ],
   day_format_narrow => [
-    "\N{U+043f}\N{U+043d}",
-    "\N{U+0432}\N{U+0442}",
-    "\N{U+0441}\N{U+0440}",
-    "\N{U+0447}\N{U+0442}",
-    "\N{U+043f}\N{U+0442}",
-    "\N{U+0441}\N{U+0431}",
-    "\N{U+0432}\N{U+0441}",
+    "\N{U+041f}",
+    "\N{U+0412}",
+    "\N{U+0421}",
+    "\N{U+0427}",
+    "\N{U+041f}",
+    "\N{U+0421}",
+    "\N{U+0412}",
   ],
   day_format_wide => [
     "\N{U+043f}\N{U+043e}\N{U+043d}\N{U+0435}\N{U+0434}\N{U+0435}\N{U+043b}\N{U+044c}\N{U+043d}\N{U+0438}\N{U+043a}",
@@ -274,5 +275,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 38,
+  version => 40,
 }
