@@ -17,8 +17,9 @@
     Ehms => "E h:mm:ss a",
     Gy => "y G",
     GyMMM => "MMM y G",
-    GyMMMEd => "E, MMM d, y G",
+    GyMMMEd => "E, d MMM y G",
     GyMMMd => "d MMM y G",
+    GyMd => "d/M/y GGGGG",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -45,7 +46,7 @@
     yM => "M/y",
     yMEd => "E, d/M/y",
     yMMM => "MMM y",
-    yMMMEd => "E, MMM d, y",
+    yMMMEd => "E, d MMM y",
     yMMMM => "MMMM y",
     yMMMd => "d MMM y",
     yMd => "d/M/y",
@@ -130,9 +131,9 @@
     "Baada ya Kristo",
   ],
   first_day_of_week => 1,
-  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
+  glibc_date_1_format => "%e %B %Y %I:%M:%S %p %Z",
   glibc_date_format => "%d/%m/%Y",
-  glibc_datetime_format => "%e %B %Y %I:%M:%S %p %Z",
+  glibc_datetime_format => "%e %B %Y %I:%M:%S %p",
   glibc_time_12_format => "%I:%M:%S %p",
   glibc_time_format => "%I:%M:%S %p",
   language => "Swahili",
@@ -269,5 +270,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 35,
+  version => 40,
 }
