@@ -16,9 +16,10 @@
     Ehm => "E h:mm a",
     Ehms => "E h:mm:ss a",
     Gy => "G y",
-    GyMMM => "G y MMM",
-    GyMMMEd => "G y MMM d, E",
-    GyMMMd => "G y MMM d",
+    GyMMM => "G MMM y",
+    GyMMMEd => "G d MMM y E",
+    GyMMMd => "G d MMM y",
+    GyMd => "GGGGG dd.MM.y",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -270,5 +271,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 39,
+  version => 40,
 }
