@@ -19,6 +19,7 @@
     GyMMM => "Gy\N{U+5e74}M\N{U+6708}",
     GyMMMEd => "Gy\N{U+5e74}M\N{U+6708}d\N{U+65e5}E",
     GyMMMd => "Gy\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
+    GyMd => "GGGGG y-MM-dd",
     H => "H\N{U+65f6}",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -42,6 +43,7 @@
     ms => "mm:ss",
     y => "y\N{U+5e74}",
     yM => "y\N{U+5e74}M\N{U+6708}",
+    yMEEEEd => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}EEEE",
     yMEd => "y/M/dE",
     yMM => "y\N{U+5e74}M\N{U+6708}",
     yMMM => "y\N{U+5e74}M\N{U+6708}",
@@ -58,9 +60,9 @@
   date_format_long => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
   date_format_medium => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
   date_format_short => "y/M/d",
-  datetime_format_full => "{1}{0}",
+  datetime_format_full => "{1} {0}",
   datetime_format_long => "{1} {0}",
-  datetime_format_medium => "{1}{0}",
+  datetime_format_medium => "{1} {0}",
   datetime_format_short => "{1} {0}",
   day_format_abbreviated => [
     "\N{U+5468}\N{U+4e00}",
@@ -263,10 +265,10 @@
   ],
   script => "Simplified",
   territory => undef,
-  time_format_full => "zzzz ah:mm:ss",
-  time_format_long => "z ah:mm:ss",
-  time_format_medium => "ah:mm:ss",
-  time_format_short => "ah:mm",
+  time_format_full => "zzzz HH:mm:ss",
+  time_format_long => "z HH:mm:ss",
+  time_format_medium => "HH:mm:ss",
+  time_format_short => "HH:mm",
   variant => undef,
-  version => 38,
+  version => 40,
 }
